@@ -3,7 +3,8 @@ SECRET_KEY = "testkeytestkey"
 INSTALLED_APPS = [
     "django.contrib.auth",
     "django.contrib.contenttypes",
-    "tuhls_core.apps.TuhlsCoreConfig",
+    "tuhls_core",
+    "tuhls_invoice",
     "example",
 ]
 AUTH_USER_MODEL = "example.User"
